/*

  Barometric Pressure Sensor Module BMP280 (6 pin)

  Parts required:
  - Arduino Board
  - Barometric Pressure Sensor Module BMP280 (6 pin)

  Library:
  - Adafruit_BMP280

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 17 Jan 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <Wire.h>                                           // include library Wire.h
#include <SPI.h>                                            // include library SPI.h
#include <Adafruit_BMP280.h>                                // include library Adafruit_BMP280.h

Adafruit_BMP280 bmp;                                        // create object from Adafruit_BMP280 called bmp

void setup()
{
  Serial.begin(9600);                                       // start Serial Monitor communication

  if (!bmp.begin(0x76))                                     // check that the BMP280 Sensor is connected to the I2C adress 0x76
  { 
    Serial.println("Error! No BMP Sensor Detected!!!");     // if not print text
    while (1);
  }
}

void loop()
{
    Serial.print("------------BMP 280 -------------\n");    // print text to Serial Monitor
    Serial.print("Temperature = ");                         // print text to Serial Monitor
    Serial.print(bmp.readTemperature());                    // read temperature and print to Serial Monitor
    Serial.println(" *C");                                  // print text to Serial Monitor
    Serial.print("Pressure = ");                            // print text to Serial Monitor
    Serial.print(bmp.readPressure() / 100);                 // read pressure and print to Serial Monitor  
    Serial.println(" mb");                                  // print text to Serial Monitor
    Serial.print("Approx Altitude = ");                     // print text to Serial Monitor
    Serial.print(bmp.readAltitude(1013.25));                // read altitude and print to Serial Monitor
    Serial.println(" m");                                   // print text to Serial Monitor
    Serial.print("--------------------------------\n");     // print text to Serial Monitor
    delay(2000);                                            // wait 2000ms
}
